==> calculate-client-3.1.7_alpha3.tar.bz2: calculate-client-3.1.7_alpha3/setup.py <==
#!/usr/bin/env python2
# -*- coding: utf-8 -*-

# setup.py --- Setup script for calculate-desktop

# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

__app__ = "calculate-client"
__version__ = "3.1.7"

import os
import stat
from distutils.core import setup, Extension
from distutils.command.install_data import install_data

data_files = []

data_files += [('/etc/init.d', ['data/client'])]
data_files += [('/usr/sbin', ['data/logout'])]
data_files += [('/usr/share/calculate/xdm/login.d',
                                                ['data/login.d/10client'])] +\
              [('/usr/share/calculate/xdm/logout.d',
                                                ['data/logout.d/10client'])] +\
              [('/usr/share/calculate/xdm/',['data/wait_domain'])]

def __scanDir(scanDir, prefix, replace_dirname, dirData, flagDir=False):
    """Scan directory"""
    files = []
    dirs = []
    if flagDir or stat.S_ISDIR(os.stat(scanDir)[stat.ST_MODE]):
        for fileOrDir in os.listdir(scanDir):
            absPath = os.path.join(scanDir, fileOrDir)
            statInfo = os.stat(absPath)[stat.ST_MODE]
            if stat.S_ISREG(statInfo):
                files.append(absPath)
            elif stat.S_ISDIR(statInfo):
                dirs.append(absPath)
        if replace_dirname:
            listDirs = list(scanDir.partition("/"))[1:]
            listDirs.insert(0, replace_dirname)
            scanDir = "".join(listDirs)
        if prefix:
            scanDir = os.path.join(prefix, scanDir)
        dirData.append((scanDir, files))
        for sDir in dirs:
            __scanDir(sDir, prefix, replace_dirname, dirData, True)
    return dirData


def create_data_files(data_dirs, prefix="", replace_dirname=""):
    """Create data_files"""
    data_files = []
    for data_dir in data_dirs:
        data = []
        data_files += __scanDir(data_dir, prefix, replace_dirname, data)
    return data_files


class cl_install_data(install_data):
    def run(self):
        install_data.run(self)
        data_file = [("/etc/init.d/client",0755),
                     ("/usr/sbin/logout",0755),
                     ("/usr/share/calculate/xdm/wait_domain",0755)]
        fileNames = map(lambda x: os.path.split(x[0])[1], data_file)
        listNames = map(lambda x: filter(lambda y: y, x[0].split("/")),
                        data_file)
        data_find = {}
        for i in range(len(fileNames)):
            listNames[i].reverse()
            data_find[fileNames[i]] = [listNames[i], data_file[i][1]]

        for path in self.get_outputs():
            nameFile = os.path.split(path)[1]
            if nameFile in data_find.keys():
                data = data_find[nameFile][0]
                mode = data_find[nameFile][1]
                flagFound = True
                iMax = len(data)
                pathFile = path
                for i in range(iMax):
                    if data[i] != os.path.split(pathFile)[1]:
                        flagFound = False
                        break
                    pathFile = os.path.split(pathFile)[0]
                if flagFound:
                    os.chmod(path, mode)


setup(
    name = __app__,
    version = __version__,
    description = "Mounting resources and synchronize the user profile",
    author = "Calculate Ltd.",
    author_email = "support@calculate.ru",
    url = "http://calculate-linux.org",
    license = "http://www.apache.org/licenses/LICENSE-2.0",
    package_dir = {'calculate.client': "client"},
    packages = ['calculate.client','calculate.client.utils',
                'calculate.client.variables'],
    data_files = data_files,
    cmdclass={'install_data': cl_install_data})

==> calculate-client-3.2.0_alpha3.tar.bz2: calculate-client-3.2.0_alpha3/setup.py <==
#!/usr/bin/env python2
# -*- coding: utf-8 -*-

# setup.py --- Setup script for calculate-desktop

# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

__app__ = "calculate-client"
__version__ = "3.2.0_alpha1"

from distutils.core import setup, Extension
from calculate.install_data import install_data

data_files = [('/etc/init.d', [('data/client',0755)]),
              ('/usr/share/calculate/xdm/login.d',
                            ['data/login.d/10client']),
              ('/usr/share/calculate/xdm/logout.d',
                            ['data/logout.d/10client']),
              ('/usr/share/calculate/xdm/',[('data/wait_domain',0755)])]

setup(
    name = __app__,
    version = __version__,
    description = "Mounting resources and synchronize the user profile",
    author = "Calculate Ltd.",
    author_email = "support@calculate.ru",
    url = "http://calculate-linux.org",
    license = "http://www.apache.org/licenses/LICENSE-2.0",
    package_dir = {'calculate.client': "client"},
    packages = ['calculate.client','calculate.client.utils',
                'calculate.client.variables'],
    data_files = data_files,
    cmdclass={'install_data': install_data})
